@@ -1,8 +1,10 @@
 _base_ = ['./twins_svt-s_uperhead_8x2_512x512_160k_ade20k.py']
+
+checkpoint = 'https://download.openmmlab.com/mmsegmentation/v0.5/pretrain/twins/alt_gvt_base_20220308-1b7eb711.pth'  # noqa
+
 model = dict(
     backbone=dict(
-        init_cfg=dict(
-            type='Pretrained', checkpoint='pretrained/alt_gvt_base.pth'),
+        init_cfg=dict(type='Pretrained', checkpoint=checkpoint),
         embed_dims=[96, 192, 384, 768],
         num_heads=[3, 6, 12, 24],
         depths=[2, 2, 18, 2]),
